@@ -1,5 +1,5 @@
 from ScraGet.forum import get_post, get_topic
-from ScraGet.project import get_project
+from ScraGet.project import get_project, project_comments
 from ScraGet.cloud import get_cloud_data, cloud
 from ScraGet.studios import get_studio
 from ScraGet.user import get_user, get_user_extra
